@@ -65,6 +65,7 @@ def command(title, subtitle, author, image):
         image_path = save_og_image(image, directory.joinpath("images/banner"))
         blog.image = image_path.relative_to(directory).as_posix()
     blog.save()
+    logging.info("start editing index.md in {blog.directory}")
 
 
 def save_og_image(image: Image, path: Path) -> Path:
@@ -103,9 +104,7 @@ def save_og_image(image: Image, path: Path) -> Path:
 @click.argument(
     "blog", type=click.Path(exists=True, file_okay=False, readable=True), required=True
 )
-@click.argument(
-    "image", type=ImageType(), required=True
-)
+@click.argument("image", type=ImageType(), required=True)
 def update_banner_command(blog, image):
     """
     of the blog.
